% Stile LaTeX per ---Ithaca: viaggio nella scienza--- una rivista di
% divulgazione e cultura scientifica edita dal Dipartimento di
% Matematica e Fisica "Ennio De Giorgi".
%
% Modalità Bozza.
%
% Basato sullo stile "Two column color article",
% http://www.howtotex.com/.
%
% Basato sullo stile "article".
%
% (c) Francesco Paparella - 2012-2013.
%
\NeedsTeXFormat{LaTeX2e} 
\ProvidesClass{ithaca_bozza}[2013/04/08 v0.9] %la data DEVE avere la 
                                              %forma yyyy/mm/dd
\LoadClass[a4paper,%
           11pt,%
           twocolumn]{article}
%
% Spazio fra le colonne
\setlength{\columnsep}{2cc}
%
% Sillabazione italiana.
\RequirePackage[italian]{babel}
%
% Margini
\RequirePackage[a4paper, left=20mm, right=20mm, top=15mm, bottom=30mm]{geometry}
%
% Pacchetti matematici AMS.
\RequirePackage{amsmath,amsfonts,amsthm}
%
% Abilita pdflatex e l'inserimento di figure. 
\RequirePackage{graphicx}
%
% Converte in .pdf le figure in .eps.
%\RequirePackage{epstopdf}
%
% Abilita l'uso di colori richiamati con i nomi svg.
%\RequirePackage[svgnames]{xcolor}
%
% In modo 'bozza' non uso il pacchetto "caption" per le didascalie delle figure.
%
% Tipografia degli indirizzi web
\RequirePackage{url}
%
% Dimensioni a scelta dei caratteri.
%\RequirePackage{fix-cm}
%
% Personalizzazioni del titolo e dei titoli di sezione:
% nel pacchetto 'bozza' non ci sono personalizzazioni.
%
% Elimino la numerazione da tutte le sezioni (e sottosezioni, etc.)
\setcounter{secnumdepth}{0}
%
% Linea orizzontale nera per il titolo
\newcommand{\HorRule}{
  \rule{\linewidth}{1pt}%
}
%
% Eventuale dotta citazione da mettere sotto al titolo
\def\@DottaCita{}
\newcommand{\dottacitazione}[2]{%
  \def\@DottaCita{%
  \begin{flushright}
    \vspace{20pt}
    \begin{minipage}{0.475\textwidth}
      \small%
      #1\\%
      \vphantom{x}\hrulefill~{\bf #2}%
    \end{minipage}\vspace{-18pt}%
  \end{flushright}%
  }%
}
\def\@TheSeries{}
\newcommand{\serie}[1]{%
  \def\@TheSeries{%
    \vspace{-5pt}%
    {\large #1}\\%
   }%
}
%
% Ridefinisco il titolo per avere la possibilità di specificare
% opzionalmente un titolo corto (non ho capito se era già previsto
% in koma-script), e per cambiare carattere, colori, etc.
\makeatletter
\def\@NoAuthor{}
\title{%
  \vspace{-30pt}%
  \begin{flushleft}%
    \HorRule%
    \\%
    \@TheSeries%
    \@TheTitle%
    \\%
  \end{flushleft}%
  \@DottaCita%
  \@NoAuthor%
}
\renewcommand{\title}[2][\@TheTitle]{\def\@ShortTitle{#1}\def\@TheTitle{#2}}
%
% Ridefinisco l'autore per cambiare carattere, colori, etc.
% Per avere più autori con rispettive affiliazioni definisco anche 
% "\name" e "\affiliation" da usarsi all'interno di \author{}.
\author{%
  \hspace{-4pt}%
  \begin{tabular*}{\textwidth}{@{}ll@{}}%
  \@TheAuthor%
  \end{tabular*}%
  \\%
  \hspace{-9pt}%
  \HorRule%
}
%
\renewcommand{\author}[1]{\def\@TheAuthor{#1}}
\newcommand{\name}[1]{\large%
  \lineskip 0.5em%
  #1&%
}
\newcommand{\affiliation}[1]{%
  \hskip 0.75em%
  \footnotesize%
  #1%
  \\%
}
% Se l'articolo non ha autori, bisogna specificare '\noauthor'
\newcommand{\noauthor}{\def\@TheAuthor{}%
  \def\@NoAuthor{\vspace{-22pt}}
}
\makeatother
%
% Elimino la data
\date{}
%
% Testate e piè di pagina.
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\RequirePackage{lastpage}	
% Testata (vuota)
\lhead{}
\chead{}
\rhead{}
\makeatletter
% Piè di pagina
\def\@TheNumber{X}
\def\@TheYear{XXXX}
\newcommand{\NUMERO}[1]{\def\@TheNumber{#1}}
\newcommand{\ANNO}[1]{\def\@TheYear{#1}}
\lfoot{\footnotesize \textbf{Nome della Rivista~\@TheNumber,~\@TheYear}~~*~~\@ShortTitle}
\makeatother
\cfoot{}
\rfoot{\footnotesize \thepage}	% "Page 1 of 2"
\renewcommand{\headrulewidth}{0.0pt}
\renewcommand{\footrulewidth}{0.4pt}
%
% Lettera iniziale ingrandita
\newcommand{\initial}[1]{%
  {\noindent\Huge\textsf{#1}}
}
%
% Definisco una versione personalizzata di "\maketitle" per
% imporre lo stile di pagina "fancy" anche alla prima pagina.
% Utile anche per future personalizzazioni.
\newcommand{\gscmaketitle}{%
  \maketitle%
  \thispagestyle{fancy}%
}
\newcommand{\ithacamaketitle}{\gscmaketitle}
%
% Definisco una versione personalizzata di "\abstract".
% La seguente macro (puro TeX) selezione il primo carattere
% del testo dell'abstract e passarlo al comando "\initial"
% per tipografarlo in grande.
\makeatletter
\def\splitfirstchar#1#2\sentinel{\initial{#1}{%
\bf%
#2%
}}
\renewcommand{\abstract}[1]{%
  \splitfirstchar#1\sentinel%
  \vspace{1ex}%
  \@afterindentfalse
  \@afterheading
}
\makeatother
%
% Comando per inserire una figura in una colonna
\newcommand{\ColumnFigure}[2]{%
  \begin{figure}[ht]
    \includegraphics[width=\columnwidth]{#1}
    \caption{#2}
  \end{figure}
}
%
% Comando per inserire una figura a larghezza di pagina
\newcommand{\WideFigure}[2]{%
  \begin{figure*}[ht]
    \includegraphics[width=\textwidth]{#1}
    \caption{#2}
  \end{figure*}
}
%
% Figura a largezza di pagina con didascalia a fianco
\newcommand{\WideFigureSideCaption}[2]{%
  \begin{figure*}[ht]
    \begin{minipage}[c][\totalheight][b]{0.7\textwidth}
      \includegraphics[width=\textwidth]{#1}%
    \end{minipage}%
    \hfill%
    \begin{minipage}[c][\totalheight][b]{0.275\textwidth}
      \vspace{-2ex}
      \caption{#2}
    \end{minipage}%
  \end{figure*}
}
%
% Comandi per le box di testo
\newcommand\boxtitle[1]{
  \textbf{#1}
}
%
\newcommand{\ocbox}[2]{%
\begin{figure}[ht]%
  \fbox{%
    \begin{minipage}[t]{1.0\columnwidth}
      \begin{center}%
        \begin{minipage}[t]{0.85\columnwidth}%
          \vspace{3ex}%
          \begin{center}
            %\begin{tikzpicture}[remember picture,overlay]   
              \boxtitle{#1}%
            %\end{tikzpicture} 
          \end{center}
          #2%
          \vspace{3ex}%
        \end{minipage}%
      \end{center}%
    \end{minipage}%
  }%
\end{figure}
}
%
\newcommand{\tcbox}[2]{%
\begin{figure*}[ht]%
  \fbox{%
    \begin{minipage}[t]{1.0\textwidth}
      \begin{center}%
        \begin{minipage}[t]{0.925\textwidth}%
          \vspace{3ex}%
          \begin{center}
            \boxtitle{#1}%
          \end{center}
          #2%
          \vspace{4ex}%
        \end{minipage}%
      \end{center}%
    \end{minipage}%
  }%
\end{figure*}
}
%
\usepackage{pifont}
\usepackage{fourier-orns}
% Bibliografia (modifiedfrom http://stackoverflow.com/questions/1037905/bibliography-as-section-in-latex-bibtex)
\makeatletter
\renewenvironment{thebibliography}[1]{
      {
        \vspace{2ex}%
        \noindent\HorRule%
      }
      \vspace{2ex}%
      \footnotesize%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist%
      \vspace{1ex}%
      \HorRule%
      % {\color{DarkGoldenrod}
      %   \hrulefill\qquad%
      %   \decofourright\qquad\starredbullet\qquad\decofourleft%
      %   \qquad\hrulefill}%
      \vspace{4ex}%
    }
\makeatother
%
% Nuovi comandi per la bibliografia.
% Citazione articoli:
%    \refer{autori}{titolo}{rivista}{vol}{anno}{pagine}
\newcommand{\refer}[6]{{\sc #1:}{\ ``#2'',}{\em\ #3}{\bf\ #4}{\ (#5),}{\ #6.}}
% Citazione libri:
%    \referbook{autori}{titolo}{editore}{anno}
\newcommand{\referbook}[4]{{\sc #1:}{\em\ #2,}{\ #3}{\ (#4).}}
%
% Comando da usare se non c'è la bibliografia
\newcommand{\nobibliography}{
  \vspace{2ex}%
  \noindent\HorRule%
  \vspace{3ex}%
}
% Se in futuro necessari, caricare altri pacchetti per la bibliografia
% a questo punto.
%
% Biografia degli autori 
%
\newcommand\AuthorsBio[2]{
  {\noindent%\color{DarkRed}
    \textbf{#1: }}{#2}\par%
  \vspace{1.5ex}%
}
%
%
%
%
%
% %http://tex.stackexchange.com/questions/25614/background-image-for-minipage
% \newsavebox\mysavebox
% \newenvironment{imgminipage}[2][]{%
%    \def\imgcmd{\includegraphics[width=\wd\mysavebox,height=\dimexpr\ht\mysavebox+\dp\mysavebox\relax,#1]{#2}}%
%    \begin{lrbox}{\mysavebox}%
%    \begin{minipage}%
% }{%
%    \end{minipage}
%    \end{lrbox}%
% %   \sbox\mysavebox{\fbox{\usebox\mysavebox}}%
%    \sbox\mysavebox{\usebox\mysavebox}%
%    \mbox{\rlap{\raisebox{-\dp\mysavebox}{\imgcmd}}\usebox\mysavebox}%
% }
